Module process

Module process 

Structs

Child
A wrapper around smol::process::Child that ensures all subprocesses are killed when the process is terminated: on Unix by using process groups, and on Windows by using job objects.