Module redact

Module redact 

Functions

redact_command
Redact a string which could include a command with environment variables
should_redact
Whether a given environment variable name should have its value redacted