pub struct TypeIdHasher { /* private fields */ }Trait Implementations
Sourceimpl Clone for TypeIdHasher
impl Clone for TypeIdHasher
Sourcefn clone(&self) -> TypeIdHasher
fn clone(&self) -> TypeIdHasher
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TypeIdHasher
Sourceimpl Default for TypeIdHasher
impl Default for TypeIdHasher
Sourcefn default() -> TypeIdHasher
fn default() -> TypeIdHasher
Returns the “default value” for a type. Read more
impl Eq for TypeIdHasher
Sourceimpl Hasher for TypeIdHasher
impl Hasher for TypeIdHasher
1.26.0 · Sourcefn write_u128(&mut self, i: u128)
fn write_u128(&mut self, i: u128)
Writes a single
u128 into this hasher.1.3.0 · Sourcefn write_usize(&mut self, i: usize)
fn write_usize(&mut self, i: usize)
Writes a single
usize into this hasher.1.26.0 · Sourcefn write_i128(&mut self, i: i128)
fn write_i128(&mut self, i: i128)
Writes a single
i128 into this hasher.1.3.0 · Sourcefn write_isize(&mut self, i: isize)
fn write_isize(&mut self, i: isize)
Writes a single
isize into this hasher.Sourcefn write_length_prefix(&mut self, len: usize)
fn write_length_prefix(&mut self, len: usize)
🔬This is a nightly-only experimental API. (
hasher_prefixfree_extras)Writes a length prefix into this hasher, as part of being prefix-free. Read more
Sourceimpl Ord for TypeIdHasher
impl Ord for TypeIdHasher
Sourcefn cmp(&self, other: &TypeIdHasher) -> Ordering
fn cmp(&self, other: &TypeIdHasher) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TypeIdHasher
impl PartialEq for TypeIdHasher
Sourcefn eq(&self, other: &TypeIdHasher) -> bool
fn eq(&self, other: &TypeIdHasher) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TypeIdHasher
impl PartialOrd for TypeIdHasher
impl StructuralPartialEq for TypeIdHasher